var NAVTREEINDEX9 =
{
"ojph__bitbuffer__write_8h.html":[3,0,0,1,0,1],
"ojph__bitbuffer__write_8h_source.html":[3,0,0,1,0,1],
"ojph__block__common_8cpp.html":[3,0,0,1,1,0],
"ojph__block__common_8cpp_source.html":[3,0,0,1,1,0],
"ojph__block__common_8h.html":[3,0,0,1,1,1],
"ojph__block__common_8h_source.html":[3,0,0,1,1,1],
"ojph__block__decoder32_8cpp.html":[3,0,0,1,1,3],
"ojph__block__decoder32_8cpp_source.html":[3,0,0,1,1,3],
"ojph__block__decoder64_8cpp.html":[3,0,0,1,1,4],
"ojph__block__decoder64_8cpp_source.html":[3,0,0,1,1,4],
"ojph__block__decoder_8h.html":[3,0,0,1,1,2],
"ojph__block__decoder_8h_source.html":[3,0,0,1,1,2],
"ojph__block__decoder__avx2_8cpp.html":[3,0,0,1,1,5],
"ojph__block__decoder__avx2_8cpp_source.html":[3,0,0,1,1,5],
"ojph__block__decoder__ssse3_8cpp.html":[3,0,0,1,1,6],
"ojph__block__decoder__ssse3_8cpp_source.html":[3,0,0,1,1,6],
"ojph__block__decoder__wasm_8cpp.html":[3,0,0,1,1,7],
"ojph__block__decoder__wasm_8cpp.html#a0cf67078bbe62fb5c8a6646084a05a95":[3,0,0,1,1,7,4],
"ojph__block__decoder__wasm_8cpp.html#a367a05242cc1da2d8811645843f2b8c3":[3,0,0,1,1,7,5],
"ojph__block__decoder__wasm_8cpp.html#a92f62c9a36f5856dc8e1477410874154":[3,0,0,1,1,7,3],
"ojph__block__decoder__wasm_8cpp.html#ad23ef8612392bd58a1bf16da297686ca":[3,0,0,1,1,7,6],
"ojph__block__decoder__wasm_8cpp_source.html":[3,0,0,1,1,7],
"ojph__block__encoder_8cpp.html":[3,0,0,1,1,8],
"ojph__block__encoder_8cpp_source.html":[3,0,0,1,1,8],
"ojph__block__encoder_8h.html":[3,0,0,1,1,9],
"ojph__block__encoder_8h_source.html":[3,0,0,1,1,9],
"ojph__block__encoder__avx2_8cpp.html":[3,0,0,1,1,10],
"ojph__block__encoder__avx2_8cpp_source.html":[3,0,0,1,1,10],
"ojph__block__encoder__avx512_8cpp.html":[3,0,0,1,1,11],
"ojph__block__encoder__avx512_8cpp_source.html":[3,0,0,1,1,11],
"ojph__codeblock_8cpp.html":[3,0,0,1,0,2],
"ojph__codeblock_8cpp_source.html":[3,0,0,1,0,2],
"ojph__codeblock_8h.html":[3,0,0,1,0,3],
"ojph__codeblock_8h_source.html":[3,0,0,1,0,3],
"ojph__codeblock__fun_8cpp.html":[3,0,0,1,0,4],
"ojph__codeblock__fun_8cpp_source.html":[3,0,0,1,0,4],
"ojph__codeblock__fun_8h.html":[3,0,0,1,0,5],
"ojph__codeblock__fun_8h_source.html":[3,0,0,1,0,5],
"ojph__codestream_8cpp.html":[3,0,0,1,0,6],
"ojph__codestream_8cpp_source.html":[3,0,0,1,0,6],
"ojph__codestream_8h.html":[3,0,0,1,2,3],
"ojph__codestream_8h_source.html":[3,0,0,1,2,3],
"ojph__codestream__avx2_8cpp.html":[3,0,0,1,0,8],
"ojph__codestream__avx2_8cpp_source.html":[3,0,0,1,0,8],
"ojph__codestream__avx_8cpp.html":[3,0,0,1,0,7],
"ojph__codestream__avx_8cpp_source.html":[3,0,0,1,0,7],
"ojph__codestream__gen_8cpp.html":[3,0,0,1,0,9],
"ojph__codestream__gen_8cpp_source.html":[3,0,0,1,0,9],
"ojph__codestream__local_8cpp.html":[3,0,0,1,0,10],
"ojph__codestream__local_8cpp_source.html":[3,0,0,1,0,10],
"ojph__codestream__local_8h.html":[3,0,0,1,0,11],
"ojph__codestream__local_8h_source.html":[3,0,0,1,0,11],
"ojph__codestream__sse2_8cpp.html":[3,0,0,1,0,13],
"ojph__codestream__sse2_8cpp_source.html":[3,0,0,1,0,13],
"ojph__codestream__sse_8cpp.html":[3,0,0,1,0,12],
"ojph__codestream__sse_8cpp_source.html":[3,0,0,1,0,12],
"ojph__codestream__wasm_8cpp.html":[3,0,0,1,0,14],
"ojph__codestream__wasm_8cpp_source.html":[3,0,0,1,0,14],
"ojph__colour_8cpp.html":[3,0,0,1,4,0],
"ojph__colour_8cpp_source.html":[3,0,0,1,4,0],
"ojph__colour_8h.html":[3,0,0,1,4,1],
"ojph__colour_8h_source.html":[3,0,0,1,4,1],
"ojph__colour__avx2_8cpp.html":[3,0,0,1,4,3],
"ojph__colour__avx2_8cpp_source.html":[3,0,0,1,4,3],
"ojph__colour__avx_8cpp.html":[3,0,0,1,4,2],
"ojph__colour__avx_8cpp_source.html":[3,0,0,1,4,2],
"ojph__colour__local_8h.html":[3,0,0,1,4,4],
"ojph__colour__local_8h_source.html":[3,0,0,1,4,4],
"ojph__colour__sse2_8cpp.html":[3,0,0,1,4,6],
"ojph__colour__sse2_8cpp_source.html":[3,0,0,1,4,6],
"ojph__colour__sse_8cpp.html":[3,0,0,1,4,5],
"ojph__colour__sse_8cpp_source.html":[3,0,0,1,4,5],
"ojph__colour__wasm_8cpp.html":[3,0,0,1,4,7],
"ojph__colour__wasm_8cpp_source.html":[3,0,0,1,4,7],
"ojph__compress_8cpp.html":[3,0,0,0,1,0],
"ojph__compress_8cpp.html#a0ddf1224851353fc92bfbff6f499fa97":[3,0,0,0,1,0,10],
"ojph__compress_8cpp.html#a3a15d3e32830bbf4dd3f2e0effed4cce":[3,0,0,0,1,0,8],
"ojph__compress_8cpp.html#a3c463d89a178db9ef4d569980022f564":[3,0,0,0,1,0,7],
"ojph__compress_8cpp.html#aaf2e6821832ba8b12ba5edb4a220ece4":[3,0,0,0,1,0,9],
"ojph__compress_8cpp_source.html":[3,0,0,0,1,0],
"ojph__defs_8h.html":[3,0,0,1,2,4],
"ojph__defs_8h.html#a0480926f2f10d84c1409ab9e7ac1fb1f":[3,0,0,1,2,4,3],
"ojph__defs_8h.html#a2c9176d8d2697bf0e930d654623447e5":[3,0,0,1,2,4,2],
"ojph__defs_8h.html#a34dff1a2ee4de923e7455ecd1cbe1748":[3,0,0,1,2,4,1],
"ojph__defs_8h.html#a43333d02537e52329d7ea8e405420c67":[3,0,0,1,2,4,0],
"ojph__defs_8h.html#a5b92cd2d30b869b1026ab6baeeb31d16":[3,0,0,1,2,4,4],
"ojph__defs_8h.html#adf52fe9ad95bc92b1e16628516698c60":[3,0,0,1,2,4,5],
"ojph__defs_8h_source.html":[3,0,0,1,2,4],
"ojph__expand_8cpp.html":[3,0,0,0,2,0],
"ojph__expand_8cpp.html#a0ddf1224851353fc92bfbff6f499fa97":[3,0,0,0,2,0,4],
"ojph__expand_8cpp.html#a3a15d3e32830bbf4dd3f2e0effed4cce":[3,0,0,0,2,0,2],
"ojph__expand_8cpp.html#a514502fec7afcc4d22c629f3a58e6ed2":[3,0,0,0,2,0,1],
"ojph__expand_8cpp.html#aaf2e6821832ba8b12ba5edb4a220ece4":[3,0,0,0,2,0,3],
"ojph__expand_8cpp_source.html":[3,0,0,0,2,0],
"ojph__file_8cpp.html":[3,0,0,1,3,1],
"ojph__file_8cpp_source.html":[3,0,0,1,3,1],
"ojph__file_8h.html":[3,0,0,1,2,5],
"ojph__file_8h_source.html":[3,0,0,1,2,5],
"ojph__img__io_8cpp.html":[3,0,0,0,4,0],
"ojph__img__io_8cpp_source.html":[3,0,0,0,4,0],
"ojph__img__io_8h.html":[3,0,0,0,0,0],
"ojph__img__io_8h_source.html":[3,0,0,0,0,0],
"ojph__img__io__avx2_8cpp.html":[3,0,0,0,4,1],
"ojph__img__io__avx2_8cpp_source.html":[3,0,0,0,4,1],
"ojph__img__io__sse41_8cpp.html":[3,0,0,0,4,2],
"ojph__img__io__sse41_8cpp_source.html":[3,0,0,0,4,2],
"ojph__mem_8c.html":[3,0,0,1,3,2],
"ojph__mem_8c.html#a059760215d877261387285b1fcd0bd28":[3,0,0,1,3,2,2],
"ojph__mem_8c.html#a4055a02605d6ecfa700885833628647d":[3,0,0,1,3,2,0],
"ojph__mem_8c.html#a490ed438b1694d2c283ed42990b44228":[3,0,0,1,3,2,1],
"ojph__mem_8c_source.html":[3,0,0,1,3,2],
"ojph__mem_8cpp.html":[3,0,0,1,3,3],
"ojph__mem_8cpp_source.html":[3,0,0,1,3,3],
"ojph__mem_8h.html":[3,0,0,1,2,6],
"ojph__mem_8h_source.html":[3,0,0,1,2,6],
"ojph__message_8cpp.html":[3,0,0,1,3,4],
"ojph__message_8cpp_source.html":[3,0,0,1,3,4],
"ojph__message_8h.html":[3,0,0,1,2,7],
"ojph__message_8h.html#a594a9eea4d979bdf573635cb77cecc62":[3,0,0,1,2,7,4],
"ojph__message_8h.html#a83fc5ef7eace1ea8edd8bc89be67d407":[3,0,0,1,2,7,6],
"ojph__message_8h.html#ae4546abbd8d73f3466a11084e562f099":[3,0,0,1,2,7,5],
"ojph__message_8h.html#afa8368270d0003264e2f80353a7c4563":[3,0,0,1,2,7,7],
"ojph__message_8h_source.html":[3,0,0,1,2,7],
"ojph__params_8cpp.html":[3,0,0,1,0,15],
"ojph__params_8cpp.html#a525335710b53cb064ca56b936120431e":[3,0,0,1,0,15,2],
"ojph__params_8cpp_source.html":[3,0,0,1,0,15],
"ojph__params_8h.html":[3,0,0,1,2,8],
"ojph__params_8h_source.html":[3,0,0,1,2,8],
"ojph__params__local_8h.html":[3,0,0,1,0,16],
"ojph__params__local_8h_source.html":[3,0,0,1,0,16],
"ojph__precinct_8cpp.html":[3,0,0,1,0,17],
"ojph__precinct_8cpp_source.html":[3,0,0,1,0,17],
"ojph__precinct_8h.html":[3,0,0,1,0,18],
"ojph__precinct_8h_source.html":[3,0,0,1,0,18],
"ojph__resolution_8cpp.html":[3,0,0,1,0,19],
"ojph__resolution_8cpp_source.html":[3,0,0,1,0,19],
"ojph__resolution_8h.html":[3,0,0,1,0,20],
"ojph__resolution_8h_source.html":[3,0,0,1,0,20],
"ojph__sockets_8cpp.html":[3,0,0,0,4,3],
"ojph__sockets_8cpp_source.html":[3,0,0,0,4,3],
"ojph__sockets_8h.html":[3,0,0,0,0,1],
"ojph__sockets_8h.html#a6f0207515a9bce1df6006e605ec8313e":[3,0,0,0,0,1,3],
"ojph__sockets_8h.html#a6f69eae8cd2f00a3a517f136c5640be6":[3,0,0,0,0,1,4],
"ojph__sockets_8h.html#a8f17f09b0e42fd3149d364b901b7151d":[3,0,0,0,0,1,2],
"ojph__sockets_8h_source.html":[3,0,0,0,0,1],
"ojph__stream__expand_8cpp.html":[3,0,0,0,3,0],
"ojph__stream__expand_8cpp.html#a0ddf1224851353fc92bfbff6f499fa97":[3,0,0,0,3,0,1],
"ojph__stream__expand_8cpp.html#a6bf7b57125195bebd62d9d02b96d921f":[3,0,0,0,3,0,0],
"ojph__stream__expand_8cpp_source.html":[3,0,0,0,3,0],
"ojph__subband_8cpp.html":[3,0,0,1,0,21],
"ojph__subband_8cpp_source.html":[3,0,0,1,0,21],
"ojph__subband_8h.html":[3,0,0,1,0,22],
"ojph__subband_8h_source.html":[3,0,0,1,0,22],
"ojph__threads_8cpp.html":[3,0,0,0,4,4],
"ojph__threads_8cpp_source.html":[3,0,0,0,4,4],
"ojph__threads_8h.html":[3,0,0,0,0,2],
"ojph__threads_8h_source.html":[3,0,0,0,0,2],
"ojph__tile_8cpp.html":[3,0,0,1,0,23],
"ojph__tile_8cpp_source.html":[3,0,0,1,0,23],
"ojph__tile_8h.html":[3,0,0,1,0,24],
"ojph__tile_8h_source.html":[3,0,0,1,0,24],
"ojph__tile__comp_8cpp.html":[3,0,0,1,0,25],
"ojph__tile__comp_8cpp_source.html":[3,0,0,1,0,25],
"ojph__tile__comp_8h.html":[3,0,0,1,0,26],
"ojph__tile__comp_8h_source.html":[3,0,0,1,0,26],
"ojph__transform_8cpp.html":[3,0,0,1,4,8],
"ojph__transform_8cpp_source.html":[3,0,0,1,4,8],
"ojph__transform_8h.html":[3,0,0,1,4,9],
"ojph__transform_8h_source.html":[3,0,0,1,4,9],
"ojph__transform__avx2_8cpp.html":[3,0,0,1,4,11],
"ojph__transform__avx2_8cpp_source.html":[3,0,0,1,4,11],
"ojph__transform__avx512_8cpp.html":[3,0,0,1,4,12],
"ojph__transform__avx512_8cpp_source.html":[3,0,0,1,4,12],
"ojph__transform__avx_8cpp.html":[3,0,0,1,4,10],
"ojph__transform__avx_8cpp_source.html":[3,0,0,1,4,10],
"ojph__transform__local_8h.html":[3,0,0,1,4,13],
"ojph__transform__local_8h_source.html":[3,0,0,1,4,13],
"ojph__transform__sse2_8cpp.html":[3,0,0,1,4,15],
"ojph__transform__sse2_8cpp_source.html":[3,0,0,1,4,15],
"ojph__transform__sse_8cpp.html":[3,0,0,1,4,14],
"ojph__transform__sse_8cpp_source.html":[3,0,0,1,4,14],
"ojph__transform__wasm_8cpp.html":[3,0,0,1,4,16],
"ojph__transform__wasm_8cpp_source.html":[3,0,0,1,4,16],
"ojph__version_8h.html":[3,0,0,1,2,9],
"ojph__version_8h.html#a2115c07ef1f29ae16add37e4d3a900c4":[3,0,0,1,2,9,2],
"ojph__version_8h.html#aa326c5258b597fb73c8027f3c66c7bb3":[3,0,0,1,2,9,0],
"ojph__version_8h.html#aa8a00aeb9a2cf1bb203958fb0cfc0c18":[3,0,0,1,2,9,1],
"ojph__version_8h_source.html":[3,0,0,1,2,9],
"ojph__wrapper_8cpp.html":[3,0,1,0,0,0],
"ojph__wrapper_8cpp.html#a15f01a53bc1ac73d6483c4145b0d54af":[3,0,1,0,0,0,18],
"ojph__wrapper_8cpp.html#a220a784fb931171ae170c51f2c09727d":[3,0,1,0,0,0,7],
"ojph__wrapper_8cpp.html#a286acf18dcb15c2d19b6473bc2933b5c":[3,0,1,0,0,0,14],
"ojph__wrapper_8cpp.html#a30de9bb4379632ac96aac601285a59de":[3,0,1,0,0,0,11],
"ojph__wrapper_8cpp.html#a346fb705a5c9f6ea9f8a3bd2b4b01f6e":[3,0,1,0,0,0,17],
"ojph__wrapper_8cpp.html#a4142b5a41f453e14969a18b01f4fb4b2":[3,0,1,0,0,0,8],
"ojph__wrapper_8cpp.html#a58a2a6ca58127eb8d52a2aa98e47b56f":[3,0,1,0,0,0,19],
"ojph__wrapper_8cpp.html#a58adecebd9ea6ca9eb3dbb6a1694dcb1":[3,0,1,0,0,0,12],
"ojph__wrapper_8cpp.html#a62dcfe2ee980c32f8b98bcf0dea7935e":[3,0,1,0,0,0,4],
"ojph__wrapper_8cpp.html#a774fcfc8f2fd2a6b50ff499df2f12183":[3,0,1,0,0,0,16],
"ojph__wrapper_8cpp.html#a7bd3f69da97b92738fbc9e8df816498a":[3,0,1,0,0,0,3],
"ojph__wrapper_8cpp.html#a7ca0f886199590c98d1c145135cb9cea":[3,0,1,0,0,0,2],
"ojph__wrapper_8cpp.html#a84eff2f84fbbb71185301eb1532466ef":[3,0,1,0,0,0,6],
"ojph__wrapper_8cpp.html#a9911f096a2a7f94bb9f64b2bb3648967":[3,0,1,0,0,0,13],
"ojph__wrapper_8cpp.html#aa1182172a81a02cf30c1dfc0394841ce":[3,0,1,0,0,0,1],
"ojph__wrapper_8cpp.html#aa8fae46b623d2a4223ba65458f519ea9":[3,0,1,0,0,0,10],
"ojph__wrapper_8cpp.html#aaa47ac3272f233d9d028311c79a87af4":[3,0,1,0,0,0,9],
"ojph__wrapper_8cpp.html#ad46f3aa801790fbe71336bb25dd156d6":[3,0,1,0,0,0,15],
"ojph__wrapper_8cpp.html#ae2e463f9236b894ab45a0bf9432c2145":[3,0,1,0,0,0,20],
"ojph__wrapper_8cpp.html#afae5539bfe3f9a92f9b16570b79056b0":[3,0,1,0,0,0,5],
"ojph__wrapper_8cpp_source.html":[3,0,1,0,0,0],
"pages.html":[],
"stream__expand__support_8cpp.html":[3,0,0,0,3,1],
"stream__expand__support_8cpp_source.html":[3,0,0,0,3,1],
"stream__expand__support_8h.html":[3,0,0,0,3,2],
"stream__expand__support_8h_source.html":[3,0,0,0,3,2],
"structimg__info.html":[2,0,1],
"structimg__info.html#a34840861b45a28a2d01835cef68b38d6":[2,0,1,8],
"structimg__info.html#a4d49b1ea81cb6362510c02e25ece29f9":[2,0,1,0],
"structimg__info.html#a64516f1a0b88ed2a72996006175ca7c4":[2,0,1,3],
"structimg__info.html#a6ea1af8bf4de32c3b7f6da5196938cc8":[2,0,1,5],
"structimg__info.html#a7deecfc7807f54bc4bc3325450161858":[2,0,1,1],
"structimg__info.html#a9f6c1877cce4aeb3aa0aedc73be5b159":[2,0,1,6],
"structimg__info.html#aa0e50b05bea796be794af017b76ad9e8":[2,0,1,9],
"structimg__info.html#ac1eb4873cd9609f753a3283baec69f7e":[2,0,1,10],
"structimg__info.html#adab22050d06c326a1085f2feaa370188":[2,0,1,2],
"structimg__info.html#ae99631395ebcf6e60470d1e1237aa977":[2,0,1,7],
"structimg__info.html#af6eb558f092564b870204f06683b11c5":[2,0,1,4],
"structimg__info.html#af6f831e7b20b55132acbf1b6a217f20d":[2,0,1,11],
"structj2k__struct.html":[2,0,2],
"structj2k__struct.html#a448515828f2f749b2f149fd45646cc8a":[2,0,2,1],
"structj2k__struct.html#acc085d565aab066ae35b6511df5434da":[2,0,2,0],
"structojph_1_1cli__interpreter_1_1arg__inter__base.html":[1,0,0,16,0],
"structojph_1_1cli__interpreter_1_1arg__inter__base.html":[2,0,0,16,0],
"structojph_1_1cli__interpreter_1_1arg__inter__base.html#a2ef864145e11c4459448a81c6f09d60e":[1,0,0,16,0,0],
"structojph_1_1cli__interpreter_1_1arg__inter__base.html#a2ef864145e11c4459448a81c6f09d60e":[2,0,0,16,0,0],
"structojph_1_1coded__lists.html":[1,0,0,30],
"structojph_1_1coded__lists.html":[2,0,0,30],
"structojph_1_1coded__lists.html#a3a945f1dae352a986d1eb632726ea511":[1,0,0,30,3],
"structojph_1_1coded__lists.html#a3a945f1dae352a986d1eb632726ea511":[2,0,0,30,3],
"structojph_1_1coded__lists.html#a739322bfb90940e3790a398fe06efcfc":[1,0,0,30,0],
"structojph_1_1coded__lists.html#a739322bfb90940e3790a398fe06efcfc":[2,0,0,30,0],
"structojph_1_1coded__lists.html#a799f7acba121dea72b627bd8330f90ac":[1,0,0,30,2],
"structojph_1_1coded__lists.html#a799f7acba121dea72b627bd8330f90ac":[2,0,0,30,2],
"structojph_1_1coded__lists.html#a7b54314b7a63664c0e074559f3e4d1cf":[1,0,0,30,4],
"structojph_1_1coded__lists.html#a7b54314b7a63664c0e074559f3e4d1cf":[2,0,0,30,4],
"structojph_1_1coded__lists.html#aa191aae4286970bfebfd6affbdbc3968":[1,0,0,30,1],
"structojph_1_1coded__lists.html#aa191aae4286970bfebfd6affbdbc3968":[2,0,0,30,1],
"structojph_1_1lifting__buf.html":[1,0,0,29],
"structojph_1_1lifting__buf.html":[2,0,0,29],
"structojph_1_1lifting__buf.html#a47cd0e21d54f77480d4b912f7997ec4c":[1,0,0,29,0]
};
